"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.Validator = exports.FailedValidationError = void 0;
/**
 * The validation error that is thrown from checkValid.
 */
class FailedValidationError extends Error {
    constructor(errors) {
        super(errors
            .map(({ path, message }) => [path.join("."), message].filter((v) => v.length > 0).join(": "))
            .join("; "));
        this.isFailedValidationError = true;
        this.errors = errors;
    }
}
exports.FailedValidationError = FailedValidationError;
/**
 * The base class of all the validators in this package. TValid is the type of any value that passes validation.
 */
class Validator {
    /**
     * Return true if the value is valid. #isValid is unique in that validation errors are not surfaced, so the validator
     * may optimize for performance.
     * @param value value to check
     */
    isValid(value) {
        return this.validate(value).length === 0;
    }
    /**
     * Validate the given value and throw if it's not valid
     * @param value that is TValid
     * @param path The path at which the value being checked was found
     */
    checkValid(value, path) {
        const errors = this.validate(value, path);
        if (errors.length > 0) {
            throw new FailedValidationError(errors);
        }
        return value;
    }
}
exports.Validator = Validator;
//# sourceMappingURL=interfaces.js.map