import { ValidationError, ValidationErrorPath, Validator } from "../interfaces";
interface ArrayValidatorOptions<TItem> {
    readonly items?: Validator<TItem>;
    readonly minLength?: number;
    readonly maxLength?: number;
}
/**
 * Validator that checks that the value is an array of a particular kind of item
 */
export default class ArrayValidator<TItem> extends Validator<TItem[]> {
    private readonly options;
    constructor(options: ArrayValidatorOptions<TItem>);
    /**
     * A valid array must have at least min elements
     * @param min min array length
     */
    minLength(min: number): ArrayValidator<TItem>;
    /**
     * A valid array must have at most max elements
     * @param max max array length
     */
    maxLength(max: number): ArrayValidator<TItem>;
    /**
     * Specify the type of the item allowed for the array validator
     * @param items type of items allowed in the array
     */
    items<TItem>(items: Validator<TItem>): ArrayValidator<TItem>;
    validate(value: any, path?: ValidationErrorPath): ValidationError[];
    isValid(value: any): value is TItem[];
}
export {};
