"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const interfaces_1 = require("../interfaces");
/**
 * Validates that a string contains JSON that when parsed matches the given validator
 */
class JsonValidator extends interfaces_1.Validator {
    constructor(parsedValidator) {
        super();
        this.parsedValidator = parsedValidator;
    }
    validate(value, path = []) {
        if (typeof value !== "string") {
            return [
                { path, message: "must be a string containing valid json", value },
            ];
        }
        let parsed;
        try {
            parsed = JSON.parse(value);
        }
        catch (error) {
            return [{ path, message: "invalid json", value }];
        }
        return this.parsedValidator.validate(parsed, path);
    }
    isValid(value) {
        try {
            return (typeof value === "string" &&
                this.parsedValidator.isValid(JSON.parse(value)));
        }
        catch (error) {
            return false;
        }
    }
}
exports.default = JsonValidator;
//# sourceMappingURL=json-validator.js.map