import { ValidationError, ValidationErrorPath, Validator } from "../interfaces";
interface NumberValidatorOptions {
    readonly multipleOf?: number;
    readonly min?: number;
    readonly max?: number;
}
export default class NumberValidator extends Validator<number> {
    private readonly options;
    constructor(options: NumberValidatorOptions);
    /**
     * Limit the number to be greater than or equal to the min
     * @param min min number
     */
    min(min: number): NumberValidator;
    /**
     * Limit the number to be less than or equal to the max
     * @param max max number
     */
    max(max: number): NumberValidator;
    /**
     * Limit the number validator to only allow numbers that are a multiple of the given value
     * @param multipleOf number that a valid value must be a multiple of
     */
    multipleOf(multipleOf: number): NumberValidator;
    /**
     * Limit the number validator to only allow integers. Alias to #multipleOf(1).
     */
    integer(): NumberValidator;
    validate(value: any, path?: ValidationErrorPath): ValidationError[];
    isValid(value: any): value is number;
}
export {};
