import { ValidationError, ValidationErrorPath, Validator } from "../interfaces";
interface StringValidatorOptions {
    readonly pattern?: RegExp;
    readonly minLength?: number;
    readonly maxLength?: number;
}
/**
 * Validates that a given value is a string with some format and minimum or maximum length.
 */
export default class StringValidator extends Validator<string> {
    private readonly options;
    constructor(options: StringValidatorOptions);
    /**
     * Return a new validator that checks the string is not shorter than the given length.
     * @param min
     */
    minLength(min: number): StringValidator;
    /**
     * Returns a new string validator that checks the string does not exceed the maximum length
     * @param max length that the string may not exceed
     */
    maxLength(max: number): StringValidator;
    /**
     * Return a string validator that checks the string matches a given pattern.
     * @param pattern to check
     */
    pattern(pattern: RegExp): StringValidator;
    /**
     * Return a string validator that checks the string is alphanumeric.
     */
    alphanum(): StringValidator;
    /**
     * Return a string validator that checks the string is a uuid.
     */
    uuid(): StringValidator;
    /**
     * Return a string validator that checks the string is a valid e-mail.
     * The regular expression is based on https://stackoverflow.com/a/46181/1126380.
     */
    email(): StringValidator;
    validate(value: any, path?: ValidationErrorPath): ValidationError[];
    isValid(value: any): value is string;
}
export {};
