"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const interfaces_1 = require("../interfaces");
/**
 * Returns a validator that checks the value is a tuple, i.e. an array with a fixed number of elements that match the
 * given validators.
 */
class TupleValidator extends interfaces_1.Validator {
    constructor(options) {
        super();
        this.options = options;
    }
    validate(value, path = []) {
        const { validators } = this.options;
        if (!Array.isArray(value)) {
            return [{ message: `must be an array`, path, value }];
        }
        let errors = [];
        for (let i = 0; i < validators.length; i++) {
            errors = errors.concat(validators[i].validate(value[i], [...path, i]));
        }
        if (value.length > validators.length) {
            errors.push({
                value,
                path,
                message: `array length ${value.length} was greater than expected length ${validators.length}`,
            });
        }
        return errors;
    }
    isValid(value) {
        const { validators } = this.options;
        if (typeof value !== "object" || !Array.isArray(value)) {
            return false;
        }
        if (value.length !== validators.length) {
            return false;
        }
        for (let i = 0; i < validators.length; i++) {
            if (!validators[i].isValid(value[i])) {
                return false;
            }
        }
        return true;
    }
}
exports.default = TupleValidator;
//# sourceMappingURL=tuple-validator.js.map